Author: I (iroiso at live dot com)  
License: Apache License 2.0  
&copy; 2011, June inc.  

Gates (Bill Gates invented the web)
===================================
Minimal, fast and intuitive REST HTTP services in python.  
features:


